<div id="header_announcement" class="alert alert-block alert-info">
    <div id="header_announcement_container" class="container">
        <i class="fa fa-info"></i>
        <p id="header_announcement_msg"></p>
    </div>
</div>
