<form class="form-horizontal">
    <div class="control-group">
        <label class="control-label" for="settings-HeaderAnnouncements-Announcement">{{ _('Announcement') }}</label>
        <div class="controls">
            <textarea id="settings-HeaderAnnouncements-Announcement"
                      class="block" rows="4"
                      data-bind="value: settings.plugins.HeaderAnnouncements.announcementText"></textarea>
        </div>
    </div>
</form>
